@@ -10,8 +10,6 @@ import os
 import pytest
 import textwrap
 
-from .utils import collapse_whitespace
-
 
 def write_json(file_path, data):
     with open(file_path, "w") as fp:
@@ -192,7 +190,7 @@ def test_output_table(db_path, options, expected):
             ]
         )
     result = CliRunner().invoke(cli.cli, ["rows", db_path, "rows"] + options)
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     assert expected == result.output.strip()
 
 
@@ -200,7 +198,7 @@ def test_create_index(db_path):
     db = Database(db_path)
     assert [] == db["Gosh"].indexes
     result = CliRunner().invoke(cli.cli, ["create-index", db_path, "Gosh", "c1"])
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     assert [
         Index(
             seq=0, name="idx_Gosh_c1", unique=0, origin="c", partial=0, columns=["c1"]
@@ -210,7 +208,7 @@ def test_create_index(db_path):
     result = CliRunner().invoke(
         cli.cli, ["create-index", db_path, "Gosh", "c2", "--name", "blah"]
     )
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     assert [
         Index(seq=0, name="blah", unique=0, origin="c", partial=0, columns=["c2"]),
         Index(
@@ -227,7 +225,7 @@ def test_create_index(db_path):
         "--unique",
     ]
     result = CliRunner().invoke(cli.cli, create_index_unique_args)
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     assert [
         Index(
             seq=0,
@@ -239,7 +237,7 @@ def test_create_index(db_path):
         )
     ] == db["Gosh2"].indexes
     # Trying to create the same index should fail
-    assert 0 != CliRunner().invoke(cli.cli, create_index_unique_args).exit_code
+    assert CliRunner().invoke(cli.cli, create_index_unique_args).exit_code != 0
     # ... unless we use --if-not-exists or --ignore
     for option in ("--if-not-exists", "--ignore"):
         assert (
@@ -273,28 +271,26 @@ def test_create_index_desc(db_path):
 @pytest.mark.parametrize(
     "col_name,col_type,expected_schema",
     (
-        ("text", "TEXT", "CREATE TABLE [dogs] ( [name] TEXT , [text] TEXT)"),
+        ("text", "TEXT", "CREATE TABLE [dogs] (\n   [name] TEXT\n, [text] TEXT)"),
         (
             "integer",
             "INTEGER",
-            "CREATE TABLE [dogs] ( [name] TEXT , [integer] INTEGER)",
+            "CREATE TABLE [dogs] (\n   [name] TEXT\n, [integer] INTEGER)",
         ),
-        ("float", "FLOAT", "CREATE TABLE [dogs] ( [name] TEXT , [float] FLOAT)"),
-        ("blob", "blob", "CREATE TABLE [dogs] ( [name] TEXT , [blob] BLOB)"),
-        ("default", None, "CREATE TABLE [dogs] ( [name] TEXT , [default] TEXT)"),
+        ("float", "FLOAT", "CREATE TABLE [dogs] (\n   [name] TEXT\n, [float] FLOAT)"),
+        ("blob", "blob", "CREATE TABLE [dogs] (\n   [name] TEXT\n, [blob] BLOB)"),
+        ("default", None, "CREATE TABLE [dogs] (\n   [name] TEXT\n, [default] TEXT)"),
     ),
 )
 def test_add_column(db_path, col_name, col_type, expected_schema):
     db = Database(db_path)
     db.create_table("dogs", {"name": str})
-    assert "CREATE TABLE [dogs] ( [name] TEXT )" == collapse_whitespace(
-        db["dogs"].schema
-    )
+    assert db["dogs"].schema == "CREATE TABLE [dogs] (\n   [name] TEXT\n)"
     args = ["add-column", db_path, "dogs", col_name]
     if col_type is not None:
         args.append(col_type)
-    assert 0 == CliRunner().invoke(cli.cli, args).exit_code
-    assert expected_schema == collapse_whitespace(db["dogs"].schema)
+    assert CliRunner().invoke(cli.cli, args).exit_code == 0
+    assert db["dogs"].schema == expected_schema
 
 
 @pytest.mark.parametrize("ignore", (True, False))
@@ -313,9 +309,7 @@ def test_add_column_ignore(db_path, ignore):
 def test_add_column_not_null_default(db_path):
     db = Database(db_path)
     db.create_table("dogs", {"name": str})
-    assert "CREATE TABLE [dogs] ( [name] TEXT )" == collapse_whitespace(
-        db["dogs"].schema
-    )
+    assert db["dogs"].schema == "CREATE TABLE [dogs] (\n   [name] TEXT\n)"
     args = [
         "add-column",
         db_path,
@@ -324,10 +318,11 @@ def test_add_column_not_null_default(db_path):
         "--not-null-default",
         "dogs'dawg",
     ]
-    assert 0 == CliRunner().invoke(cli.cli, args).exit_code
-    assert (
-        "CREATE TABLE [dogs] ( [name] TEXT , [nickname] TEXT NOT NULL DEFAULT 'dogs''dawg')"
-        == collapse_whitespace(db["dogs"].schema)
+    assert CliRunner().invoke(cli.cli, args).exit_code == 0
+    assert db["dogs"].schema == (
+        "CREATE TABLE [dogs] (\n"
+        "   [name] TEXT\n"
+        ", [nickname] TEXT NOT NULL DEFAULT 'dogs''dawg')"
     )
 
 
@@ -354,7 +349,7 @@ def test_add_foreign_key(db_path, args, assert_message):
         ]
     )
     assert (
-        0 == CliRunner().invoke(cli.cli, ["add-foreign-key", db_path] + args).exit_code
+        CliRunner().invoke(cli.cli, ["add-foreign-key", db_path] + args).exit_code == 0
     ), assert_message
     assert [
         ForeignKey(
@@ -366,7 +361,7 @@ def test_add_foreign_key(db_path, args, assert_message):
     result = CliRunner().invoke(
         cli.cli, ["add-foreign-key", db_path, "books", "author_id", "authors", "id"]
     )
-    assert 0 != result.exit_code
+    assert result.exit_code != 0
     assert (
         "Error: Foreign key already exists for author_id => authors.id"
         == result.output.strip()
@@ -377,13 +372,13 @@ def test_add_foreign_key(db_path, args, assert_message):
         cli.cli,
         ["add-foreign-key", db_path, "books", "author_id", "authors", "id", "--ignore"],
     )
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
 
     # Error if we try against an invalid column
     result = CliRunner().invoke(
         cli.cli, ["add-foreign-key", db_path, "books", "author_id", "authors", "bad"]
     )
-    assert 0 != result.exit_code
+    assert result.exit_code != 0
     assert "Error: No such column: authors.bad" == result.output.strip()
 
 
@@ -395,10 +390,12 @@ def test_add_column_foreign_key(db_path):
     result = CliRunner().invoke(
         cli.cli, ["add-column", db_path, "books", "author_id", "--fk", "authors"]
     )
-    assert 0 == result.exit_code, result.output
-    assert (
-        "CREATE TABLE [books] ( [title] TEXT , [author_id] INTEGER, FOREIGN KEY([author_id]) REFERENCES [authors]([id]) )"
-        == collapse_whitespace(db["books"].schema)
+    assert result.exit_code == 0, result.output
+    assert db["books"].schema == (
+        'CREATE TABLE "books" (\n'
+        "   [title] TEXT,\n"
+        "   [author_id] INTEGER REFERENCES [authors]([id])\n"
+        ")"
     )
     # Try it again with a custom --fk-col
     result = CliRunner().invoke(
@@ -414,18 +411,19 @@ def test_add_column_foreign_key(db_path):
             "name",
         ],
     )
-    assert 0 == result.exit_code, result.output
-    assert (
-        "CREATE TABLE [books] ( [title] TEXT , [author_id] INTEGER, [author_name_ref] TEXT, "
-        "FOREIGN KEY([author_id]) REFERENCES [authors]([id]), "
-        "FOREIGN KEY([author_name_ref]) REFERENCES [authors]([name]) )"
-        == collapse_whitespace(db["books"].schema)
+    assert result.exit_code == 0, result.output
+    assert db["books"].schema == (
+        'CREATE TABLE "books" (\n'
+        "   [title] TEXT,\n"
+        "   [author_id] INTEGER REFERENCES [authors]([id]),\n"
+        "   [author_name_ref] TEXT REFERENCES [authors]([name])\n"
+        ")"
     )
     # Throw an error if the --fk table does not exist
     result = CliRunner().invoke(
         cli.cli, ["add-column", db_path, "books", "author_id", "--fk", "bobcats"]
     )
-    assert 0 != result.exit_code
+    assert result.exit_code != 0
     assert "table 'bobcats' does not exist" in str(result.exception)
 
 
@@ -449,7 +447,7 @@ def test_index_foreign_keys(db_path):
     db = Database(db_path)
     assert [] == db["books"].indexes
     result = CliRunner().invoke(cli.cli, ["index-foreign-keys", db_path])
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     assert [["author_id"], ["author_name_ref"]] == [
         i.columns for i in db["books"].indexes
     ]
@@ -461,7 +459,7 @@ def test_enable_fts(db_path):
     result = CliRunner().invoke(
         cli.cli, ["enable-fts", db_path, "Gosh", "c1", "--fts4"]
     )
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     assert "Gosh_fts" == db["Gosh"].detect_fts()
 
     # Table names with restricted chars are handled correctly.
@@ -480,7 +478,7 @@ def test_enable_fts(db_path):
             "porter",
         ],
     )
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     assert "http://example.com_fts" == db["http://example.com"].detect_fts()
     # Check tokenize was set to porter
     assert (
@@ -528,7 +526,7 @@ def test_enable_fts_with_triggers(db_path):
         )
         .exit_code
     )
-    assert 0 == exit_code
+    assert exit_code == 0
 
     def search(q):
         return (
@@ -549,7 +547,7 @@ def test_populate_fts(db_path):
         .invoke(cli.cli, ["enable-fts", db_path, "Gosh", "c1", "--fts4"])
         .exit_code
     )
-    assert 0 == exit_code
+    assert exit_code == 0
 
     def search(q):
         return (
@@ -564,7 +562,7 @@ def test_populate_fts(db_path):
     exit_code = (
         CliRunner().invoke(cli.cli, ["populate-fts", db_path, "Gosh", "c1"]).exit_code
     )
-    assert 0 == exit_code
+    assert exit_code == 0
     assert [("martha",)] == search("martha")
 
 
@@ -582,13 +580,13 @@ def test_disable_fts(db_path):
         "Gosh_fts_docsize",
     } == set(db.table_names())
     exit_code = CliRunner().invoke(cli.cli, ["disable-fts", db_path, "Gosh"]).exit_code
-    assert 0 == exit_code
+    assert exit_code == 0
     assert {"Gosh", "Gosh2"} == set(db.table_names())
 
 
 def test_vacuum(db_path):
     result = CliRunner().invoke(cli.cli, ["vacuum", db_path])
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
 
 
 def test_dump(db_path):
@@ -617,7 +615,7 @@ def test_optimize(db_path, tables):
         db["Gosh2"].enable_fts(["c1", "c2", "c3"], fts_version="FTS5")
     size_before_optimize = os.stat(db_path).st_size
     result = CliRunner().invoke(cli.cli, ["optimize", db_path] + tables)
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     size_after_optimize = os.stat(db_path).st_size
     # Weirdest thing: tests started failing because size after
     # ended up larger than size before in some cases. I think
@@ -625,7 +623,7 @@ def test_optimize(db_path, tables):
     assert size_after_optimize <= (size_before_optimize + 10000)
     # Soundness check that --no-vacuum doesn't throw errors:
     result = CliRunner().invoke(cli.cli, ["optimize", "--no-vacuum", db_path])
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
 
 
 def test_rebuild_fts_fixes_docsize_error(db_path):
@@ -653,7 +651,7 @@ def test_rebuild_fts_fixes_docsize_error(db_path):
     assert db["fts5_table_fts_docsize"].count == 20000
     # Running rebuild-fts should fix this
     result = CliRunner().invoke(cli.cli, ["rebuild-fts", db_path, "fts5_table"])
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     assert db["fts5_table_fts_docsize"].count == 10000
 
 
@@ -676,7 +674,7 @@ def test_query_csv(db_path, format, expected):
     result = CliRunner().invoke(
         cli.cli, [db_path, "select id, name, age from dogs", format]
     )
-    assert 0 == result.exit_code
+    assert result.exit_code == 0
     assert result.output.replace("\r", "") == expected
     # Test the no-headers option:
     result = CliRunner().invoke(
@@ -1027,7 +1025,7 @@ def test_upsert(db_path, tmpdir):
         ["insert", db_path, "dogs", json_path, "--pk", "id"],
         catch_exceptions=False,
     )
-    assert 0 == result.exit_code, result.output
+    assert result.exit_code == 0, result.output
     assert 2 == db["dogs"].count
     # Now run the upsert to update just their ages
     upsert_dogs = [
@@ -1040,7 +1038,7 @@ def test_upsert(db_path, tmpdir):
         ["upsert", db_path, "dogs", json_path, "--pk", "id"],
         catch_exceptions=False,
     )
-    assert 0 == result.exit_code, result.output
+    assert result.exit_code == 0, result.output
     assert list(db.query("select * from dogs order by id")) == [
         {"id": 1, "name": "Cleo", "age": 5},
         {"id": 2, "name": "Nixie", "age": 5},
@@ -1073,7 +1071,7 @@ def test_upsert_analyze(db_path, tmpdir):
         ["upsert", db_path, "rows", "-", "--nl", "--analyze", "--pk", "id"],
         input='{"id": 2, "foo": "bar", "n": 1}',
     )
-    assert 0 == result.exit_code, result.output
+    assert result.exit_code == 0, result.output
     assert "sqlite_stat1" in db.table_names()
 
 
@@ -1100,14 +1098,14 @@ def test_upsert_alter(db_path, tmpdir):
     result = CliRunner().invoke(
         cli.cli, ["insert", db_path, "dogs", json_path, "--pk", "id"]
     )
-    assert 0 == result.exit_code, result.output
+    assert result.exit_code == 0, result.output
     # Should fail with error code if no --alter
     upsert_dogs = [{"id": 1, "age": 5}]
     write_json(json_path, upsert_dogs)
     result = CliRunner().invoke(
         cli.cli, ["upsert", db_path, "dogs", json_path, "--pk", "id"]
     )
-    assert 1 == result.exit_code
+    assert result.exit_code == 1
     assert (
         "Error: no such column: age\n\n"
         "sql = UPDATE [dogs] SET [age] = ? WHERE [id] = ?\n"
@@ -1117,10 +1115,10 @@ def test_upsert_alter(db_path, tmpdir):
     result = CliRunner().invoke(
         cli.cli, ["upsert", db_path, "dogs", json_path, "--pk", "id", "--alter"]
     )
-    assert 0 == result.exit_code
-    assert [
+    assert result.exit_code == 0
+    assert list(db.query("select * from dogs order by id")) == [
         {"id": 1, "name": "Cleo", "age": 5},
-    ] == list(db.query("select * from dogs order by id"))
+    ]
 
 
 @pytest.mark.parametrize(
@@ -1187,7 +1185,7 @@ def test_create_table(args, schema):
             + args,
             catch_exceptions=False,
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         db = Database("test.db")
         assert schema == db["t"].schema
 
@@ -1217,7 +1215,7 @@ def test_create_table_foreign_key():
             result = runner.invoke(
                 cli.cli, ["create-table", "books.db"] + args, catch_exceptions=False
             )
-            assert 0 == result.exit_code
+            assert result.exit_code == 0
         db = Database("books.db")
         assert (
             "CREATE TABLE [authors] (\n"
@@ -1242,7 +1240,7 @@ def test_create_table_error_if_table_exists():
         result = runner.invoke(
             cli.cli, ["create-table", "test.db", "dogs", "id", "integer"]
         )
-        assert 1 == result.exit_code
+        assert result.exit_code == 1
         assert (
             'Error: Table "dogs" already exists. Use --replace to delete and replace it.'
             == result.output.strip()
@@ -1257,7 +1255,7 @@ def test_create_table_ignore():
         result = runner.invoke(
             cli.cli, ["create-table", "test.db", "dogs", "id", "integer", "--ignore"]
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         assert "CREATE TABLE [dogs] (\n   [name] TEXT\n)" == db["dogs"].schema
 
 
@@ -1269,7 +1267,7 @@ def test_create_table_replace():
         result = runner.invoke(
             cli.cli, ["create-table", "test.db", "dogs", "id", "integer", "--replace"]
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         assert "CREATE TABLE [dogs] (\n   [id] INTEGER\n)" == db["dogs"].schema
 
 
@@ -1280,7 +1278,7 @@ def test_create_view():
         result = runner.invoke(
             cli.cli, ["create-view", "test.db", "version", "select sqlite_version()"]
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         assert "CREATE VIEW version AS select sqlite_version()" == db["version"].schema
 
 
@@ -1292,7 +1290,7 @@ def test_create_view_error_if_view_exists():
         result = runner.invoke(
             cli.cli, ["create-view", "test.db", "version", "select sqlite_version()"]
         )
-        assert 1 == result.exit_code
+        assert result.exit_code == 1
         assert (
             'Error: View "version" already exists. Use --replace to delete and replace it.'
             == result.output.strip()
@@ -1314,7 +1312,7 @@ def test_create_view_ignore():
                 "--ignore",
             ],
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         assert (
             "CREATE VIEW version AS select sqlite_version() + 1" == db["version"].schema
         )
@@ -1335,7 +1333,7 @@ def test_create_view_replace():
                 "--replace",
             ],
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         assert "CREATE VIEW version AS select sqlite_version()" == db["version"].schema
 
 
@@ -1353,7 +1351,7 @@ def test_drop_table():
                 "t",
             ],
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         assert "t" not in db.table_names()
 
 
@@ -1370,14 +1368,14 @@ def test_drop_table_error():
                 "t2",
             ],
         )
-        assert 1 == result.exit_code
+        assert result.exit_code == 1
         assert 'Error: Table "t2" does not exist' == result.output.strip()
         # Using --ignore suppresses that error
         result = runner.invoke(
             cli.cli,
             ["drop-table", "test.db", "t2", "--ignore"],
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
 
 
 def test_drop_view():
@@ -1394,7 +1392,7 @@ def test_drop_view():
                 "hello",
             ],
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         assert "hello" not in db.view_names()
 
 
@@ -1411,14 +1409,14 @@ def test_drop_view_error():
                 "t2",
             ],
         )
-        assert 1 == result.exit_code
+        assert result.exit_code == 1
         assert 'Error: View "t2" does not exist' == result.output.strip()
         # Using --ignore suppresses that error
         result = runner.invoke(
             cli.cli,
             ["drop-view", "test.db", "t2", "--ignore"],
         )
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
 
 
 def test_enable_wal():
@@ -1430,7 +1428,7 @@ def test_enable_wal():
             db["t"].create({"pk": int}, pk="pk")
             assert db.journal_mode == "delete"
         result = runner.invoke(cli.cli, ["enable-wal"] + dbs, catch_exceptions=False)
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         for dbname in dbs:
             db = Database(dbname)
             assert db.journal_mode == "wal"
@@ -1446,7 +1444,7 @@ def test_disable_wal():
             db.enable_wal()
             assert db.journal_mode == "wal"
         result = runner.invoke(cli.cli, ["disable-wal"] + dbs)
-        assert 0 == result.exit_code
+        assert result.exit_code == 0
         for dbname in dbs:
             db = Database(dbname)
             assert db.journal_mode == "delete"
@@ -1647,10 +1645,52 @@ def test_transform(db_path, args, expected_schema):
     assert schema == expected_schema
 
 
-def test_transform_drop_foreign_key(db_path):
+@pytest.mark.parametrize(
+    "extra_args,expected_schema",
+    (
+        (
+            ["--drop-foreign-key", "country"],
+            (
+                'CREATE TABLE "places" (\n'
+                "   [id] INTEGER PRIMARY KEY,\n"
+                "   [name] TEXT,\n"
+                "   [country] INTEGER,\n"
+                "   [city] INTEGER REFERENCES [city]([id]),\n"
+                "   [continent] INTEGER\n"
+                ")"
+            ),
+        ),
+        (
+            ["--drop-foreign-key", "country", "--drop-foreign-key", "city"],
+            (
+                'CREATE TABLE "places" (\n'
+                "   [id] INTEGER PRIMARY KEY,\n"
+                "   [name] TEXT,\n"
+                "   [country] INTEGER,\n"
+                "   [city] INTEGER,\n"
+                "   [continent] INTEGER\n"
+                ")"
+            ),
+        ),
+        (
+            ["--add-foreign-key", "continent", "continent", "id"],
+            (
+                'CREATE TABLE "places" (\n'
+                "   [id] INTEGER PRIMARY KEY,\n"
+                "   [name] TEXT,\n"
+                "   [country] INTEGER REFERENCES [country]([id]),\n"
+                "   [city] INTEGER REFERENCES [city]([id]),\n"
+                "   [continent] INTEGER REFERENCES [continent]([id])\n"
+                ")"
+            ),
+        ),
+    ),
+)
+def test_transform_add_or_drop_foreign_key(db_path, extra_args, expected_schema):
     db = Database(db_path)
     with db.conn:
         # Create table with three foreign keys so we can drop two of them
+        db["continent"].insert({"id": 1, "name": "Europe"}, pk="id")
         db["country"].insert({"id": 1, "name": "France"}, pk="id")
         db["city"].insert({"id": 24, "name": "Paris"}, pk="id")
         db["places"].insert(
@@ -1659,6 +1699,7 @@ def test_transform_drop_foreign_key(db_path):
                 "name": "Caveau de la Huchette",
                 "country": 1,
                 "city": 24,
+                "continent": 1,
             },
             foreign_keys=("country", "city"),
             pk="id",
@@ -1669,21 +1710,12 @@ def test_transform_drop_foreign_key(db_path):
             "transform",
             db_path,
             "places",
-            "--drop-foreign-key",
-            "country",
-        ],
+        ]
+        + extra_args,
     )
-    print(result.output)
     assert result.exit_code == 0
     schema = db["places"].schema
-    assert schema == (
-        'CREATE TABLE "places" (\n'
-        "   [id] INTEGER PRIMARY KEY,\n"
-        "   [name] TEXT,\n"
-        "   [country] INTEGER,\n"
-        "   [city] INTEGER REFERENCES [city]([id])\n"
-        ")"
-    )
+    assert schema == expected_schema
 
 
 _common_other_schema = (
@@ -1700,8 +1732,7 @@ _common_other_schema = (
                 'CREATE TABLE "trees" (\n'
                 "   [id] INTEGER PRIMARY KEY,\n"
                 "   [address] TEXT,\n"
-                "   [species_id] INTEGER,\n"
-                "   FOREIGN KEY([species_id]) REFERENCES [species]([id])\n"
+                "   [species_id] INTEGER REFERENCES [species]([id])\n"
                 ")"
             ),
             _common_other_schema,
@@ -1712,8 +1743,7 @@ _common_other_schema = (
                 'CREATE TABLE "trees" (\n'
                 "   [id] INTEGER PRIMARY KEY,\n"
                 "   [address] TEXT,\n"
-                "   [custom_table_id] INTEGER,\n"
-                "   FOREIGN KEY([custom_table_id]) REFERENCES [custom_table]([id])\n"
+                "   [custom_table_id] INTEGER REFERENCES [custom_table]([id])\n"
                 ")"
             ),
             "CREATE TABLE [custom_table] (\n   [id] INTEGER PRIMARY KEY,\n   [species] TEXT\n)",
@@ -1724,8 +1754,7 @@ _common_other_schema = (
                 'CREATE TABLE "trees" (\n'
                 "   [id] INTEGER PRIMARY KEY,\n"
                 "   [address] TEXT,\n"
-                "   [custom_fk] INTEGER,\n"
-                "   FOREIGN KEY([custom_fk]) REFERENCES [species]([id])\n"
+                "   [custom_fk] INTEGER REFERENCES [species]([id])\n"
                 ")"
             ),
             _common_other_schema,
@@ -1735,8 +1764,7 @@ _common_other_schema = (
             'CREATE TABLE "trees" (\n'
             "   [id] INTEGER PRIMARY KEY,\n"
             "   [address] TEXT,\n"
-            "   [species_id] INTEGER,\n"
-            "   FOREIGN KEY([species_id]) REFERENCES [species]([id])\n"
+            "   [species_id] INTEGER REFERENCES [species]([id])\n"
             ")",
             "CREATE TABLE [species] (\n   [id] INTEGER PRIMARY KEY,\n   [species] TEXT\n)",
         ),
