@@ -50,6 +50,16 @@ def test_convert_where(fresh_db, where, where_args):
     assert list(table.rows) == [{"id": 1, "title": "One"}, {"id": 2, "title": "TWO"}]
 
 
+def test_convert_skip_false(fresh_db):
+    table = fresh_db["table"]
+    table.insert_all([{"x": 0}, {"x": 1}])
+    assert table.get(1)["x"] == 0
+    assert table.get(2)["x"] == 1
+    table.convert("x", lambda x: x + 1, skip_false=False)
+    assert table.get(1)["x"] == 1
+    assert table.get(2)["x"] == 2
+
+
 @pytest.mark.parametrize(
     "drop,expected",
     (
@@ -137,3 +147,12 @@ def test_convert_multi_exception(fresh_db):
     table.insert({"title": "Mixed Case"})
     with pytest.raises(BadMultiValues):
         table.convert("title", lambda v: v.upper(), multi=True)
+
+
+def test_convert_repeated(fresh_db):
+    table = fresh_db["table"]
+    col = "num"
+    table.insert({col: 1})
+    table.convert(col, lambda x: x * 2)
+    table.convert(col, lambda _x: 0)
+    assert table.get(1) == {col: 0}
